@@ -13,50 +13,48 @@ UT_ENABLE=${UT_ENABLE:-0}
 
 if [ $CMAKE = "mingw64-cmake" ]; then
     BUILD_DIR=build_win64
+    MINGW_TRIPLE=x86_64-w64-mingw32
 else
     BUILD_DIR=build_win32
+    MINGW_TRIPLE=i686-w64-mingw32
 fi
 export FREEDVGUIDIR=${PWD}
 export CODEC2DIR=$FREEDVGUIDIR/codec2
 export LPCNETDIR=$FREEDVGUIDIR/LPCNet
 
-CODEC2_BRANCH=v1.0.5
-LPCNET_BRANCH=v0.3
-
-# First build and install vanilla codec2 as we need -lcodec2 to build LPCNet
-cd $FREEDVGUIDIR
-git clone https://github.com/drowe67/codec2.git
-cd codec2 && git switch master && git pull && git checkout $CODEC2_BRANCH
-mkdir -p $BUILD_DIR && cd $BUILD_DIR && rm -Rf *
-$CMAKE .. && make
+CODEC2_BRANCH=master
+LPCNET_BRANCH=master
 
 # OK, build and test LPCNet
 cd $FREEDVGUIDIR
 git clone https://github.com/drowe67/LPCNet.git
 cd $LPCNETDIR && git switch master && git pull && git checkout $LPCNET_BRANCH
 mkdir -p $BUILD_DIR && cd $BUILD_DIR && rm -Rf *
-$CMAKE -DCODEC2_BUILD_DIR=$CODEC2DIR/$BUILD_DIR ..
+$CMAKE ..
 make
 
-# Re-build codec2 with LPCNet and test FreeDV 2020 support
-cd $CODEC2DIR/$BUILD_DIR && rm -Rf *
-$CMAKE -DLPCNET_BUILD_DIR=$LPCNETDIR/$BUILD_DIR ..
-make VERBOSE=1
+# Build codec2 with LPCNet and test FreeDV 2020 support
+# First build and install vanilla codec2 as we need -lcodec2 to build LPCNet
+cd $FREEDVGUIDIR
+if [ ! -d codec2 ]; then
+    git clone https://github.com/drowe67/codec2.git
+fi
+cd codec2 && git switch master && git pull && git checkout $CODEC2_BRANCH
+mkdir -p $BUILD_DIR && cd $BUILD_DIR && rm -Rf * && $CMAKE -DLPCNET_BUILD_DIR=$LPCNETDIR/$BUILD_DIR .. && make VERBOSE=1
 
-cd $FREEDVGUIDIR && git pull
+cd $FREEDVGUIDIR
+if [ -d .git ]; then
+    git pull
+fi
 mkdir -p $BUILD_DIR && cd $BUILD_DIR 
 if [ $CLEAN -eq 1 ]; then rm -Rf *; fi
 
 if [ $BOOTSTRAP_WX -eq 1 ]; then
-    # build wxWidgets
-    $CMAKE -DBOOTSTRAP_WXWIDGETS=1 -DCMAKE_BUILD_TYPE=Debug -DCODEC2_BUILD_DIR=$CODEC2DIR/$BUILD_DIR -DLPCNET_BUILD_DIR=$LPCNETDIR/$BUILD_DIR ..
-    make VERBOSE=1
-
     # build freedv-gui
-    $CMAKE -DBOOTSTRAP_WXWIDGETS=1 -DUNITTEST=$UT_ENABLE -DCMAKE_BUILD_TYPE=Debug -DCODEC2_BUILD_DIR=$CODEC2DIR/$BUILD_DIR -DLPCNET_BUILD_DIR=$LPCNETDIR/$BUILD_DIR ..
-    make VERBOSE=1
+    $CMAKE -DBOOTSTRAP_WXWIDGETS=1 -DCMAKE_BUILD_TYPE=Debug -DCODEC2_BUILD_DIR=$CODEC2DIR/$BUILD_DIR -DLPCNET_BUILD_DIR=$LPCNETDIR/$BUILD_DIR ..
+    make VERBOSE=1 -j4
 else
     # build freedv-gui
     $CMAKE -DCMAKE_BUILD_TYPE=Debug -DUNITTEST=$UT_ENABLE -DCODEC2_BUILD_DIR=$CODEC2DIR/$BUILD_DIR -DLPCNET_BUILD_DIR=$LPCNETDIR/$BUILD_DIR ..
-    make VERBOSE=1
+    make VERBOSE=1 -j4
 fi
