@@ -35,7 +35,7 @@
 #define MAX_F_HZ            3000    // max freq on Waterfall and Spectrum
 #define STEP_F_HZ           500     // major (e.g. text legend) freq step on Waterfall and Spectrum graticule
 #define STEP_MINOR_F_HZ     100     // minor (ticks) freq step on Waterfall and Spectrum graticule
-#define WATERFALL_SECS_Y    30      // number of seconds respresented by y axis of waterfall
+#define WATERFALL_SECS_Y    30      // number of seconds represented by y axis of waterfall
 #define WATERFALL_SECS_STEP 5       // graticule y axis steps of waterfall
 #define DT                  0.1     // time between real time graphing updates
 #define FS                  8000    // FDMDV modem sample rate
@@ -101,4 +101,7 @@ enum
 
 #define PLUGIN_MAX_PARAMS 4
 
+// FreeDV Reporter info
+#define FREEDV_REPORTER_DEFAULT_HOSTNAME "freedv-reporter.k6aq.net"
+
 #endif  //__FDMDV2_DEFINES__
