@@ -54,19 +54,19 @@ OptionsDlg::OptionsDlg(wxWindow* parent, wxWindowID id, const wxString& title, c
     // Create notebook and tabs.
     m_notebook = new wxNotebook(panel, wxID_ANY);
     m_reportingTab = new wxPanel(m_notebook, wxID_ANY);
+    m_rigControlTab = new wxPanel(m_notebook, wxID_ANY);
     m_displayTab = new wxPanel(m_notebook, wxID_ANY);
     m_keyerTab = new wxPanel(m_notebook, wxID_ANY);
     m_modemTab = new wxPanel(m_notebook, wxID_ANY);
     m_simulationTab = new wxPanel(m_notebook, wxID_ANY);
-    m_interfacingTab = new wxPanel(m_notebook, wxID_ANY);
     m_debugTab = new wxPanel(m_notebook, wxID_ANY);
     
     m_notebook->AddPage(m_reportingTab, _("Reporting"));
+    m_notebook->AddPage(m_rigControlTab, _("Rig Control"));
     m_notebook->AddPage(m_displayTab, _("Display"));
-    m_notebook->AddPage(m_keyerTab, _("Voice Keyer"));
+    m_notebook->AddPage(m_keyerTab, _("Audio"));
     m_notebook->AddPage(m_modemTab, _("Modem"));
     m_notebook->AddPage(m_simulationTab, _("Simulation"));
-    m_notebook->AddPage(m_interfacingTab, _("UDP"));
     m_notebook->AddPage(m_debugTab, _("Debugging"));
     
     bSizer30->Add(m_notebook, 0, wxALL | wxEXPAND, 3);
@@ -89,29 +89,92 @@ OptionsDlg::OptionsDlg(wxWindow* parent, wxWindowID id, const wxString& title, c
     sizerReporting->Add(sbSizer_callSign,0, wxALL | wxEXPAND, 5);
  
     //----------------------------------------------------------
-    // PSK Reporter 
+    // Reporting Options 
     //----------------------------------------------------------
 
-    wxStaticBoxSizer* sbSizer_psk;
-    wxStaticBox* sb_psk = new wxStaticBox(m_reportingTab, wxID_ANY, _("PSK Reporter"));
-    sbSizer_psk = new wxStaticBoxSizer(sb_psk, wxHORIZONTAL);
-    m_ckbox_psk_enable = new wxCheckBox(m_reportingTab, wxID_ANY, _("Enable Reporting"), wxDefaultPosition, wxDefaultSize, wxCHK_2STATE);
-    sbSizer_psk->Add(m_ckbox_psk_enable, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
+    wxStaticBoxSizer* sbSizerReportingRows;
+    wxBoxSizer* sbSizerReportingGeneral = new wxBoxSizer(wxHORIZONTAL);
+    
+    wxStaticBox* sbReporting = new wxStaticBox(m_reportingTab, wxID_ANY, _("Reporting"));
+    
+    sbSizerReportingRows = new wxStaticBoxSizer(sbReporting, wxVERTICAL);
+    m_ckboxReportingEnable = new wxCheckBox(m_reportingTab, wxID_ANY, _("Enable Reporting"), wxDefaultPosition, wxDefaultSize, wxCHK_2STATE);
+    sbSizerReportingGeneral->Add(m_ckboxReportingEnable, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
     
     wxStaticText* labelPskCallsign = new wxStaticText(m_reportingTab, wxID_ANY, wxT("Callsign:"), wxDefaultPosition, wxDefaultSize, 0);
-    sbSizer_psk->Add(labelPskCallsign, 0,  wxALL | wxALIGN_CENTER_VERTICAL, 5);
+    sbSizerReportingGeneral->Add(labelPskCallsign, 0,  wxALL | wxALIGN_CENTER_VERTICAL, 5);
     
     m_txt_callsign = new wxTextCtrl(m_reportingTab, wxID_ANY,  wxEmptyString, wxDefaultPosition, wxSize(90,-1), 0, wxTextValidator(wxFILTER_ALPHANUMERIC));
-    sbSizer_psk->Add(m_txt_callsign, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
+    sbSizerReportingGeneral->Add(m_txt_callsign, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
     
     wxStaticText* labelPskGridSquare = new wxStaticText(m_reportingTab, wxID_ANY, wxT("Grid Square:"), wxDefaultPosition, wxDefaultSize, 0);
-    sbSizer_psk->Add(labelPskGridSquare, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
+    sbSizerReportingGeneral->Add(labelPskGridSquare, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
     
     m_txt_grid_square = new wxTextCtrl(m_reportingTab, wxID_ANY,  wxEmptyString, wxDefaultPosition, wxSize(70,-1), 0, wxTextValidator(wxFILTER_ALPHANUMERIC));
-    sbSizer_psk->Add(m_txt_grid_square, 0,  wxALL | wxALIGN_CENTER_VERTICAL, 5);
+    sbSizerReportingGeneral->Add(m_txt_grid_square, 0,  wxALL | wxALIGN_CENTER_VERTICAL, 5);
+    
+    sbSizerReportingRows->Add(sbSizerReportingGeneral, 0, wxALL | wxEXPAND, 5);
+    
+    // PSK Reporter options
+    wxBoxSizer* sbSizerReportingPSK = new wxBoxSizer(wxHORIZONTAL);
+    m_ckboxPskReporterEnable = new wxCheckBox(m_reportingTab, wxID_ANY, _("Enable PSK Reporter"), wxDefaultPosition, wxDefaultSize, wxCHK_2STATE);
+    sbSizerReportingPSK->Add(m_ckboxPskReporterEnable, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
+    sbSizerReportingRows->Add(sbSizerReportingPSK, 0, wxALL | wxEXPAND, 5);
+    
+    // FreeDV Reporter options
+    wxBoxSizer* sbSizerReportingFreeDV = new wxBoxSizer(wxHORIZONTAL);
+    m_ckboxFreeDVReporterEnable = new wxCheckBox(m_reportingTab, wxID_ANY, _("Enable FreeDV Reporter"), wxDefaultPosition, wxDefaultSize, wxCHK_2STATE);
+    sbSizerReportingFreeDV->Add(m_ckboxFreeDVReporterEnable, 0,  wxALL | wxALIGN_CENTER_VERTICAL, 5);
+    
+    wxStaticText* labelFreeDVHostName = new wxStaticText(m_reportingTab, wxID_ANY, wxT("Hostname:"), wxDefaultPosition, wxDefaultSize, 0);
+    m_freedvReporterHostname = new wxTextCtrl(m_reportingTab, wxID_ANY,  wxEmptyString, wxDefaultPosition, wxSize(250, -1), 0);
+    sbSizerReportingFreeDV->Add(labelFreeDVHostName, 0,  wxALL | wxALIGN_CENTER_VERTICAL, 5);
+    sbSizerReportingFreeDV->Add(m_freedvReporterHostname, 0,  wxALL | wxALIGN_CENTER_VERTICAL, 5);
+    
+    sbSizerReportingRows->Add(sbSizerReportingFreeDV, 0, wxALL | wxEXPAND, 5);
+    
+    sizerReporting->Add(sbSizerReportingRows, 0, wxALL | wxEXPAND, 5);
+    
+    // Callsign list settings
+    wxStaticBoxSizer* sbSizer_callsign_list;
+    wxStaticBox* sb_callsignList = new wxStaticBox(m_reportingTab, wxID_ANY, _("Callsign List"));
+    sbSizer_callsign_list = new wxStaticBoxSizer(sb_callsignList, wxHORIZONTAL);
+    m_ckbox_use_utc_time = new wxCheckBox(m_reportingTab, wxID_ANY, _("Use UTC Time"), wxDefaultPosition, wxDefaultSize, wxCHK_2STATE);
+    sbSizer_callsign_list->Add(m_ckbox_use_utc_time, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
+    
+    sizerReporting->Add(sbSizer_callsign_list,0, wxALL | wxEXPAND, 5);
     
-    sizerReporting->Add(sbSizer_psk,0, wxALL | wxEXPAND, 5);
     m_reportingTab->SetSizer(sizerReporting);
+    
+    // Rig Control tab
+    wxBoxSizer* sizerRigControl = new wxBoxSizer(wxVERTICAL);
+    
+    //------------------------------
+    // Rig Control options
+    //------------------------------
+    
+    wxStaticBoxSizer* sbSizer_ptt;
+    wxStaticBox *sb_ptt = new wxStaticBox(m_rigControlTab, wxID_ANY, _("PTT Options"));
+    sbSizer_ptt = new wxStaticBoxSizer(sb_ptt, wxVERTICAL);
+    
+    m_ckboxEnableSpacebarForPTT = new wxCheckBox(m_rigControlTab, wxID_ANY, _("Enable Space key for PTT"), wxDefaultPosition, wxDefaultSize, wxCHK_2STATE);
+    sbSizer_ptt->Add(m_ckboxEnableSpacebarForPTT, 0, wxALL | wxALIGN_LEFT, 5);
+    
+    sizerRigControl->Add(sbSizer_ptt,0, wxALL | wxEXPAND, 5);
+    
+    wxStaticBoxSizer* sbSizer_hamlib;
+    wxStaticBox *sb_hamlib = new wxStaticBox(m_rigControlTab, wxID_ANY, _("Hamlib Options"));
+    sbSizer_hamlib = new wxStaticBoxSizer(sb_hamlib, wxVERTICAL);
+    
+    m_ckboxEnableFreqModeChanges = new wxCheckBox(m_rigControlTab, wxID_ANY, _("Enable frequency and mode changes"), wxDefaultPosition, wxDefaultSize, wxCHK_2STATE);
+    sbSizer_hamlib->Add(m_ckboxEnableFreqModeChanges, 0, wxALL | wxALIGN_LEFT, 5);
+    
+    m_ckboxUseAnalogModes = new wxCheckBox(m_rigControlTab, wxID_ANY, _("Use USB/LSB instead of DIGU/DIGL"), wxDefaultPosition, wxDefaultSize, wxCHK_2STATE);
+    sbSizer_hamlib->Add(m_ckboxUseAnalogModes, 0, wxALL | wxALIGN_LEFT, 5);
+
+    sizerRigControl->Add(sbSizer_hamlib,0, wxALL | wxEXPAND, 5);
+    
+    m_rigControlTab->SetSizer(sizerRigControl);
         
     // Display tab
     wxBoxSizer* sizerDisplay = new wxBoxSizer(wxVERTICAL);
@@ -177,6 +240,29 @@ OptionsDlg::OptionsDlg(wxWindow* parent, wxWindowID id, const wxString& title, c
     
     m_keyerTab->SetSizer(sizerKeyer);
     
+    //------------------------------
+    // Quick Record
+    //------------------------------
+    
+    wxStaticBoxSizer* sbsQuickRecord = new wxStaticBoxSizer( new wxStaticBox(m_keyerTab, wxID_ANY, _("Quick Record")), wxVERTICAL);
+
+    wxBoxSizer* quickRecordSizer = new wxBoxSizer(wxHORIZONTAL);
+
+    wxStaticText *staticTextQRPath = new wxStaticText(m_keyerTab, wxID_ANY, _("Location to save recordings: "), wxDefaultPosition, wxDefaultSize, 0);
+    quickRecordSizer->Add(staticTextQRPath, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
+
+    m_txtCtrlQuickRecordPath = new wxTextCtrl(m_keyerTab, wxID_ANY, wxEmptyString, wxDefaultPosition, wxSize(300,-1), 0);
+    m_txtCtrlQuickRecordPath->SetToolTip(_("Location which to save recordings started via the Record button in the main window."));
+    quickRecordSizer->Add(m_txtCtrlQuickRecordPath, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
+
+    m_buttonChooseQuickRecordPath = new wxButton(m_keyerTab, wxID_APPLY, _("Choose"), wxDefaultPosition, wxSize(-1,-1), 0);
+    m_buttonChooseQuickRecordPath->SetMinSize(wxSize(120, -1));
+    quickRecordSizer->Add(m_buttonChooseQuickRecordPath, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
+    
+    sbsQuickRecord->Add(quickRecordSizer);
+    
+    sizerKeyer->Add(sbsQuickRecord,0, wxALL | wxEXPAND, 5);
+    
     // Modem tab
     wxBoxSizer* sizerModem = new wxBoxSizer(wxVERTICAL);
     
@@ -313,33 +399,6 @@ OptionsDlg::OptionsDlg(wxWindow* parent, wxWindowID id, const wxString& title, c
     sizerSimulation->Add(sbSizer_tone,0, wxALL|wxEXPAND, 5);
 
     m_simulationTab->SetSizer(sizerSimulation);
-    
-    // Interfacing tab
-    wxBoxSizer* sizerInterfacing = new wxBoxSizer(wxVERTICAL);
-    
-    //----------------------------------------------------------
-    // UDP Send Messages on Events
-    //----------------------------------------------------------
-
-    wxStaticBoxSizer* sbSizer_udp;
-    wxStaticBox* sb_udp = new wxStaticBox(m_interfacingTab, wxID_ANY, _("UDP Messages"));
-    sbSizer_udp = new wxStaticBoxSizer(sb_udp, wxVERTICAL);
-    m_ckbox_udp_enable = new wxCheckBox(m_interfacingTab, wxID_ANY, _("Enable UDP Messages"), wxDefaultPosition, wxDefaultSize, wxCHK_2STATE);
-    sbSizer_udp->Add(m_ckbox_udp_enable, 0, wxALL, 5);
-
-    wxBoxSizer* portNumberSizer = new wxBoxSizer(wxHORIZONTAL);
-    wxStaticText* udpPortNumberLabel = new wxStaticText(m_interfacingTab, wxID_ANY, _("UDP Port Number:"), wxDefaultPosition, wxDefaultSize, 0);
-    portNumberSizer->Add(udpPortNumberLabel, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
-
-    m_txt_udp_port = new wxTextCtrl(m_interfacingTab, wxID_ANY,  wxEmptyString, wxDefaultPosition, wxSize(70,-1), 0, wxTextValidator(wxFILTER_DIGITS));
-    portNumberSizer->Add(m_txt_udp_port, 0, wxALL, 5);
-    m_btn_udp_test = new wxButton(m_interfacingTab, wxID_ANY, _("Test"), wxDefaultPosition, wxDefaultSize, 0);
-    portNumberSizer->Add(m_btn_udp_test, 0, wxALL | wxALIGN_LEFT | wxALIGN_CENTER_VERTICAL, 5);
-
-    sbSizer_udp->Add(portNumberSizer, 0, wxALL, 5);
-    sizerInterfacing->Add(sbSizer_udp, 0, wxALL | wxEXPAND, 5);
-
-    m_interfacingTab->SetSizer(sizerInterfacing);
         
     // Debug tab
     wxBoxSizer* sizerDebug = new wxBoxSizer(wxVERTICAL);
@@ -447,10 +506,14 @@ OptionsDlg::OptionsDlg(wxWindow* parent, wxWindowID id, const wxString& title, c
     //-------------------
     // Tab ordering for accessibility
     //-------------------
-    m_txtCtrlCallSign->MoveBeforeInTabOrder(m_ckbox_psk_enable);
-    m_ckbox_psk_enable->MoveBeforeInTabOrder(m_txt_callsign);
+    m_txtCtrlCallSign->MoveBeforeInTabOrder(m_ckboxReportingEnable);
+    m_ckboxReportingEnable->MoveBeforeInTabOrder(m_txt_callsign);
     m_txt_callsign->MoveBeforeInTabOrder(m_txt_grid_square);
     
+    m_txt_grid_square->MoveBeforeInTabOrder(m_ckboxPskReporterEnable);
+    m_ckboxPskReporterEnable->MoveBeforeInTabOrder(m_ckboxFreeDVReporterEnable);
+    m_ckboxFreeDVReporterEnable->MoveBeforeInTabOrder(m_freedvReporterHostname);
+    
     m_waterfallColorScheme1->MoveBeforeInTabOrder(m_waterfallColorScheme2);
     m_waterfallColorScheme2->MoveBeforeInTabOrder(m_waterfallColorScheme3);
     
@@ -473,9 +536,6 @@ OptionsDlg::OptionsDlg(wxWindow* parent, wxWindowID id, const wxString& title, c
     m_ckboxTone->MoveBeforeInTabOrder(m_txtToneFreqHz);
     m_txtToneFreqHz->MoveBeforeInTabOrder(m_txtToneAmplitude);
     
-    m_ckbox_udp_enable->MoveBeforeInTabOrder(m_txt_udp_port);
-    m_txt_udp_port->MoveBeforeInTabOrder(m_btn_udp_test);
-    
     m_txtCtrlFifoSize->MoveBeforeInTabOrder(m_ckboxVerbose);
     m_ckboxVerbose->MoveBeforeInTabOrder(m_ckboxTxRxThreadPriority);
     m_ckboxTxRxThreadPriority->MoveBeforeInTabOrder(m_ckboxTxRxDumpTiming);
@@ -487,8 +547,7 @@ OptionsDlg::OptionsDlg(wxWindow* parent, wxWindowID id, const wxString& title, c
     m_displayTab->MoveBeforeInTabOrder(m_keyerTab);
     m_keyerTab->MoveBeforeInTabOrder(m_modemTab);
     m_modemTab->MoveBeforeInTabOrder(m_simulationTab);
-    m_simulationTab->MoveBeforeInTabOrder(m_interfacingTab);
-    m_interfacingTab->MoveBeforeInTabOrder(m_debugTab);
+    m_simulationTab->MoveBeforeInTabOrder(m_debugTab);
     
     m_notebook->MoveBeforeInTabOrder(m_sdbSizer5OK);
     m_sdbSizer5OK->MoveBeforeInTabOrder(m_sdbSizer5Cancel);
@@ -515,15 +574,18 @@ OptionsDlg::OptionsDlg(wxWindow* parent, wxWindowID id, const wxString& title, c
 
     m_buttonChooseVoiceKeyerWaveFile->Connect(wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(OptionsDlg::OnChooseVoiceKeyerWaveFile), NULL, this);
 
-    m_BtnFifoReset->Connect(wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(OptionsDlg::OnFifoReset), NULL, this);
-    m_btn_udp_test->Connect(wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(OptionsDlg::OnUDPTest), NULL, this);
+    m_buttonChooseQuickRecordPath->Connect(wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(OptionsDlg::OnChooseQuickRecordPath), NULL, this);
 
-    m_ckbox_psk_enable->Connect(wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler(OptionsDlg::OnPSKReporterEnable), NULL, this);
+    m_BtnFifoReset->Connect(wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(OptionsDlg::OnFifoReset), NULL, this);
+
+    m_ckboxReportingEnable->Connect(wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler(OptionsDlg::OnReportingEnable), NULL, this);
+    m_ckboxFreeDVReporterEnable->Connect(wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler(OptionsDlg::OnReportingEnable), NULL, this);
     m_ckboxTone->Connect(wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler(OptionsDlg::OnToneStateEnable), NULL, this);
-    m_ckbox_udp_enable->Connect(wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler(OptionsDlg::OnUDPStateEnable), NULL, this);
     
     m_ckboxMultipleRx->Connect(wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler(OptionsDlg::OnMultipleRxEnable), NULL, this);
     
+    m_ckboxEnableFreqModeChanges->Connect(wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler(OptionsDlg::OnFreqModeChangeEnable), NULL, this);
+    
     event_in_serial = 0;
     event_out_serial = 0;
 }
@@ -549,19 +611,21 @@ OptionsDlg::~OptionsDlg()
     m_ckboxFreeDV700txClip->Disconnect(wxEVT_COMMAND_CHECKBOX_CLICKED, wxScrollEventHandler(OptionsDlg::OnFreeDV700txClip), NULL, this);
     m_ckboxFreeDV700Combine->Disconnect(wxEVT_COMMAND_CHECKBOX_CLICKED, wxScrollEventHandler(OptionsDlg::OnFreeDV700Combine), NULL, this);
     m_buttonChooseVoiceKeyerWaveFile->Disconnect(wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(OptionsDlg::OnChooseVoiceKeyerWaveFile), NULL, this);
+    m_buttonChooseQuickRecordPath->Disconnect(wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(OptionsDlg::OnChooseQuickRecordPath), NULL, this);
 
     m_BtnFifoReset->Disconnect(wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(OptionsDlg::OnFifoReset), NULL, this);
-    m_btn_udp_test->Disconnect(wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(OptionsDlg::OnUDPTest), NULL, this);
 
 #ifdef __WXMSW__
     m_ckboxDebugConsole->Disconnect(wxEVT_COMMAND_CHECKBOX_CLICKED, wxScrollEventHandler(OptionsDlg::OnDebugConsole), NULL, this);
 #endif
     
-    m_ckbox_psk_enable->Disconnect(wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler(OptionsDlg::OnPSKReporterEnable), NULL, this);
+    m_ckboxReportingEnable->Disconnect(wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler(OptionsDlg::OnReportingEnable), NULL, this);
+    m_ckboxFreeDVReporterEnable->Disconnect(wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler(OptionsDlg::OnReportingEnable), NULL, this);
     m_ckboxTone->Disconnect(wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler(OptionsDlg::OnToneStateEnable), NULL, this);
-    m_ckbox_udp_enable->Disconnect(wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler(OptionsDlg::OnUDPStateEnable), NULL, this);
     
     m_ckboxMultipleRx->Disconnect(wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler(OptionsDlg::OnMultipleRxEnable), NULL, this);
+    
+    m_ckboxEnableFreqModeChanges->Disconnect(wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler(OptionsDlg::OnFreqModeChangeEnable), NULL, this);
 }
 
 
@@ -574,12 +638,18 @@ void OptionsDlg::ExchangeData(int inout, bool storePersistent)
     {
         m_txtCtrlCallSign->SetValue(wxGetApp().m_callSign);
 
+        m_ckboxEnableSpacebarForPTT->SetValue(wxGetApp().m_boolEnableSpacebarForPTT);
+        m_ckboxUseAnalogModes->SetValue(wxGetApp().m_boolHamlibUseAnalogModes);
+        m_ckboxEnableFreqModeChanges->SetValue(wxGetApp().m_boolHamlibEnableFreqModeChanges);
+        
         /* Voice Keyer */
 
         m_txtCtrlVoiceKeyerWaveFile->SetValue(wxGetApp().m_txtVoiceKeyerWaveFile);
         m_txtCtrlVoiceKeyerRxPause->SetValue(wxString::Format(wxT("%i"), wxGetApp().m_intVoiceKeyerRxPause));
         m_txtCtrlVoiceKeyerRepeats->SetValue(wxString::Format(wxT("%i"), wxGetApp().m_intVoiceKeyerRepeats));
 
+        m_txtCtrlQuickRecordPath->SetValue(wxGetApp().m_txtQuickRecordPath);
+        
         m_ckHalfDuplex->SetValue(wxGetApp().m_boolHalfDuplex);
 
         m_ckboxMultipleRx->SetValue(wxGetApp().m_boolMultipleRx);
@@ -597,9 +667,6 @@ void OptionsDlg::ExchangeData(int inout, bool storePersistent)
         m_ckboxAttnCarrierEn->SetValue(wxGetApp().m_attn_carrier_en);
         m_txtAttnCarrier->SetValue(wxString::Format(wxT("%i"),wxGetApp().m_attn_carrier));
 
-        m_ckbox_udp_enable->SetValue(wxGetApp().m_udp_enable);
-        m_txt_udp_port->SetValue(wxString::Format(wxT("%i"),wxGetApp().m_udp_port));
-
         m_txtCtrlFifoSize->SetValue(wxString::Format(wxT("%i"),wxGetApp().m_fifoSize_ms));
 
         m_ckboxTxRxThreadPriority->SetValue(wxGetApp().m_txRxThreadHighPriority);
@@ -616,10 +683,20 @@ void OptionsDlg::ExchangeData(int inout, bool storePersistent)
         m_ckboxDebugConsole->SetValue(wxGetApp().m_debug_console);
 #endif
         
-        // PSK Reporter config
-        m_ckbox_psk_enable->SetValue(wxGetApp().m_psk_enable);
-        m_txt_callsign->SetValue(wxGetApp().m_psk_callsign);
-        m_txt_grid_square->SetValue(wxGetApp().m_psk_grid_square);
+        // General reporting config
+        m_ckboxReportingEnable->SetValue(wxGetApp().m_reportingEnabled);
+        m_txt_callsign->SetValue(wxGetApp().m_reportingCallsign);
+        m_txt_grid_square->SetValue(wxGetApp().m_reportingGridSquare);
+
+        // PSK Reporter options
+        m_ckboxPskReporterEnable->SetValue(wxGetApp().m_pskReporterEnabled);
+        
+        // FreeDV Reporter options
+        m_ckboxFreeDVReporterEnable->SetValue(wxGetApp().m_freedvReporterEnabled);
+        m_freedvReporterHostname->SetValue(wxGetApp().m_freedvReporterHostname);
+                
+        // Callsign list config
+        m_ckbox_use_utc_time->SetValue(wxGetApp().m_useUTCTime);
         
         // Stats reset time
         m_statsResetTime->SetValue(wxString::Format(wxT("%i"), wxGetApp().m_statsResetTimeSec));
@@ -659,16 +736,25 @@ void OptionsDlg::ExchangeData(int inout, bool storePersistent)
         }
         
         // Update control state based on checkbox state.
-        updatePSKReporterState();
+        updateReportingState();
         updateChannelNoiseState();
         updateAttnCarrierState();
         updateToneState();
-        updateUDPState();
         updateMultipleRxState();
+        updateRigControlState();
     }
 
     if(inout == EXCHANGE_DATA_OUT)
     {
+        wxGetApp().m_boolEnableSpacebarForPTT = m_ckboxEnableSpacebarForPTT->GetValue();
+        pConfig->Write(wxT("/Rig/EnableSpacebarForPTT"), wxGetApp().m_boolEnableSpacebarForPTT);
+        
+        wxGetApp().m_boolHamlibUseAnalogModes = m_ckboxUseAnalogModes->GetValue();
+        pConfig->Write(wxT("/Hamlib/UseAnalogModes"), wxGetApp().m_boolHamlibUseAnalogModes);
+        
+        wxGetApp().m_boolHamlibEnableFreqModeChanges = m_ckboxEnableFreqModeChanges->GetValue();
+        pConfig->Write(wxT("/Hamlib/EnableFreqModeChanges"), wxGetApp().m_boolHamlibEnableFreqModeChanges);
+        
         wxGetApp().m_callSign = m_txtCtrlCallSign->GetValue();
 
         wxGetApp().m_boolHalfDuplex = m_ckHalfDuplex->GetValue();
@@ -691,7 +777,10 @@ void OptionsDlg::ExchangeData(int inout, bool storePersistent)
         if (tmp < 0) {tmp = 0;} if (tmp > 100) {tmp = 100;}
         wxGetApp().m_intVoiceKeyerRepeats = (int)tmp;
         pConfig->Write(wxT("/VoiceKeyer/Repeats"), wxGetApp().m_intVoiceKeyerRepeats);
-
+        
+        wxGetApp().m_txtQuickRecordPath = m_txtCtrlQuickRecordPath->GetValue();
+        pConfig->Write(wxT("/QuickRecord/SavePath"), wxGetApp().m_txtQuickRecordPath);
+        
         wxGetApp().m_testFrames    = m_ckboxTestFrame->GetValue();
 
         wxGetApp().m_channel_noise = m_ckboxChannelNoise->GetValue();
@@ -722,11 +811,6 @@ void OptionsDlg::ExchangeData(int inout, bool storePersistent)
         g_verbose = m_ckboxVerbose->GetValue();
         g_freedv_verbose = m_ckboxFreeDVAPIVerbose->GetValue();
 
-        wxGetApp().m_udp_enable     = m_ckbox_udp_enable->GetValue();
-        long port;
-        m_txt_udp_port->GetValue().ToLong(&port);
-        wxGetApp().m_udp_port       = (int)port;
-
         wxGetApp().m_FreeDV700txClip = m_ckboxFreeDV700txClip->GetValue();
         wxGetApp().m_FreeDV700txBPF = m_ckboxFreeDV700txBPF->GetValue();
         wxGetApp().m_FreeDV700Combine = m_ckboxFreeDV700Combine->GetValue();
@@ -735,10 +819,20 @@ void OptionsDlg::ExchangeData(int inout, bool storePersistent)
         wxGetApp().m_debug_console = m_ckboxDebugConsole->GetValue();
 #endif
 
-        // PSK Reporter config
-        wxGetApp().m_psk_enable = m_ckbox_psk_enable->GetValue();
-        wxGetApp().m_psk_callsign = m_txt_callsign->GetValue();
-        wxGetApp().m_psk_grid_square = m_txt_grid_square->GetValue();
+        // General reporting config
+        wxGetApp().m_reportingEnabled = m_ckboxReportingEnable->GetValue();
+        wxGetApp().m_reportingCallsign = m_txt_callsign->GetValue();
+        wxGetApp().m_reportingGridSquare = m_txt_grid_square->GetValue();
+
+        // PSK Reporter options
+        wxGetApp().m_pskReporterEnabled = m_ckboxPskReporterEnable->GetValue();
+        
+        // FreeDV Reporter options
+        wxGetApp().m_freedvReporterEnabled = m_ckboxFreeDVReporterEnable->GetValue();
+        wxGetApp().m_freedvReporterHostname = m_freedvReporterHostname->GetValue();
+                
+        // Callsign list config
+        wxGetApp().m_useUTCTime = m_ckbox_use_utc_time->GetValue();
         
         // Waterfall color
         if (m_waterfallColorScheme1->GetValue())
@@ -765,9 +859,6 @@ void OptionsDlg::ExchangeData(int inout, bool storePersistent)
             pConfig->Write(wxT("/Data/TextEncoding"), wxGetApp().m_textEncoding);
 #endif
 
-            pConfig->Write(wxT("/UDP/enable"), wxGetApp().m_udp_enable);
-            pConfig->Write(wxT("/UDP/port"),  wxGetApp().m_udp_port);
-
             pConfig->Write(wxT("/FreeDV700/txClip"), wxGetApp().m_FreeDV700txClip);
             pConfig->Write(wxT("/FreeDV700/txBPF"), wxGetApp().m_FreeDV700txBPF);
 
@@ -779,9 +870,19 @@ void OptionsDlg::ExchangeData(int inout, bool storePersistent)
             pConfig->Write(wxT("/Debug/verbose"), g_verbose);
             pConfig->Write(wxT("/Debug/APIverbose"), g_freedv_verbose);
 
-            pConfig->Write(wxT("/PSKReporter/Enable"), wxGetApp().m_psk_enable);
-            pConfig->Write(wxT("/PSKReporter/Callsign"), wxGetApp().m_psk_callsign);
-            pConfig->Write(wxT("/PSKReporter/GridSquare"), wxGetApp().m_psk_grid_square);
+            // General reporting parameters
+            pConfig->Write(wxT("/Reporting/Enable"), wxGetApp().m_reportingEnabled);
+            pConfig->Write(wxT("/Reporting/Callsign"), wxGetApp().m_reportingCallsign);
+            pConfig->Write(wxT("/Reporting/GridSquare"), wxGetApp().m_reportingGridSquare);
+        
+            // PSK Reporter parameters
+            pConfig->Write(wxT("/Reporting/PSKReporter/Enable"), wxGetApp().m_pskReporterEnabled);
+    
+            // FreDV Reporter options
+            pConfig->Write(wxT("/Reporting/FreeDV/Enable"), wxGetApp().m_freedvReporterEnabled);
+            pConfig->Write(wxT("/Reporting/FreeDV/Hostname"), wxGetApp().m_freedvReporterHostname);
+            
+            pConfig->Write(wxT("/CallsignList/UseUTCTime"), wxGetApp().m_useUTCTime);
             
             pConfig->Write(wxT("/Stats/ResetTime"), wxGetApp().m_statsResetTimeSec);
             
@@ -861,6 +962,19 @@ void OptionsDlg::OnChooseVoiceKeyerWaveFile(wxCommandEvent& event) {
      m_txtCtrlVoiceKeyerWaveFile->SetValue(wxGetApp().m_txtVoiceKeyerWaveFile);
 }
 
+void OptionsDlg::OnChooseQuickRecordPath(wxCommandEvent& event) {
+     wxDirDialog pathDialog(
+                                 this,
+                                 wxT("Choose Quick Record save location"),
+                                 wxGetApp().m_txtQuickRecordPath
+                                 );
+     if(pathDialog.ShowModal() == wxID_CANCEL) {
+         return;     // the user changed their mind...
+     }
+
+     m_txtCtrlQuickRecordPath->SetValue(pathDialog.GetPath());
+}
+
 //  Run time update of carrier amplitude attenuation
 
 void OptionsDlg::OnAttnCarrierEn(wxScrollEvent& event) {
@@ -923,38 +1037,51 @@ void OptionsDlg::OnFifoReset(wxCommandEvent& event)
     }
 }
 
-void OptionsDlg::OnUDPTest(wxCommandEvent& event)
-{
-    char s[80];
-    snprintf(s, 80, "hello from FreeDV!");
-    UDPSend(wxGetApp().m_udp_port, s, strlen(s)+1);
-}
-
-void OptionsDlg::updatePSKReporterState()
+void OptionsDlg::updateReportingState()
 {
     if (!sessionActive_)
     {
-        m_ckbox_psk_enable->Enable(true);
-        if (m_ckbox_psk_enable->GetValue())
+        m_ckbox_use_utc_time->Enable(true);
+        m_ckboxReportingEnable->Enable(true);
+        if (m_ckboxReportingEnable->GetValue())
         {
             m_txtCtrlCallSign->Enable(false);
             m_txt_callsign->Enable(true);
             m_txt_grid_square->Enable(true);
+            m_ckboxPskReporterEnable->Enable(true);
+            m_ckboxFreeDVReporterEnable->Enable(true);
+            
+            if (m_ckboxFreeDVReporterEnable->GetValue())
+            {
+                m_freedvReporterHostname->Enable(true);
+            }
+            else
+            {
+                m_freedvReporterHostname->Enable(false);
+            }
         }
         else
         {
             m_txtCtrlCallSign->Enable(true);
             m_txt_callsign->Enable(false);
             m_txt_grid_square->Enable(false);
+            m_ckboxPskReporterEnable->Enable(false);
+            m_ckboxFreeDVReporterEnable->Enable(false);
+            m_freedvReporterHostname->Enable(false);
         }    
     }
     else
     {
-        // Txt Msg/PSK Reporter options cannot be modified during a session.
-        m_ckbox_psk_enable->Enable(false);
+        // Txt Msg/Reporter options cannot be modified during a session.
+        m_ckboxReportingEnable->Enable(false);
         m_txtCtrlCallSign->Enable(false);
         m_txt_callsign->Enable(false);
         m_txt_grid_square->Enable(false);
+        m_ckboxPskReporterEnable->Enable(false);
+        m_ckboxFreeDVReporterEnable->Enable(false);
+        m_freedvReporterHostname->Enable(false);
+        
+        m_ckbox_use_utc_time->Enable(false);
     }
 }
 
@@ -974,12 +1101,6 @@ void OptionsDlg::updateToneState()
     m_txtToneAmplitude->Enable(m_ckboxTone->GetValue());
 }
 
-void OptionsDlg::updateUDPState()
-{
-    m_txt_udp_port->Enable(m_ckbox_udp_enable->GetValue());
-    m_btn_udp_test->Enable(m_ckbox_udp_enable->GetValue());
-}
-
 void OptionsDlg::updateMultipleRxState()
 {
     if (!sessionActive_)
@@ -995,9 +1116,26 @@ void OptionsDlg::updateMultipleRxState()
     }
 }
 
-void OptionsDlg::OnPSKReporterEnable(wxCommandEvent& event)
+void OptionsDlg::updateRigControlState()
 {
-    updatePSKReporterState();
+    if (!sessionActive_)
+    {
+        m_ckboxEnableFreqModeChanges->Enable(true);
+        m_ckboxEnableSpacebarForPTT->Enable(true);
+        m_ckboxUseAnalogModes->Enable(m_ckboxEnableFreqModeChanges->GetValue());
+    }
+    else
+    {
+        // Rig control settings cannot be updated during a session.
+        m_ckboxUseAnalogModes->Enable(false);
+        m_ckboxEnableFreqModeChanges->Enable(false);
+        m_ckboxEnableSpacebarForPTT->Enable(false);
+    }
+}
+    
+void OptionsDlg::OnReportingEnable(wxCommandEvent& event)
+{
+    updateReportingState();
 }
 
 void OptionsDlg::OnToneStateEnable(wxCommandEvent& event)
@@ -1005,16 +1143,16 @@ void OptionsDlg::OnToneStateEnable(wxCommandEvent& event)
     updateToneState();
 }
 
-void OptionsDlg::OnUDPStateEnable(wxCommandEvent& event)
-{
-    updateUDPState();
-}
-
 void OptionsDlg::OnMultipleRxEnable(wxCommandEvent& event)
 {
     updateMultipleRxState();
 }
 
+void OptionsDlg::OnFreqModeChangeEnable(wxCommandEvent& event)
+{
+    updateRigControlState();
+}
+
 void OptionsDlg::DisplayFifoPACounters() {
     const int STR_LENGTH = 256;
     
