@@ -46,7 +46,7 @@ class OptionsDlg : public wxDialog
         {
             sessionActive_ = active; 
         
-            updatePSKReporterState();
+            updateReportingState();
         }
         
     protected:
@@ -67,25 +67,30 @@ class OptionsDlg : public wxDialog
         void    OnDebugConsole(wxScrollEvent& event);
 
         void    OnFifoReset(wxCommandEvent& event);
-        void    OnUDPTest(wxCommandEvent& event);
         
-        void    OnPSKReporterEnable(wxCommandEvent& event);
+        void    OnReportingEnable(wxCommandEvent& event);
         void    OnToneStateEnable(wxCommandEvent& event);
-        void    OnUDPStateEnable(wxCommandEvent& event);
         void    OnMultipleRxEnable(wxCommandEvent& event);
+        void    OnFreqModeChangeEnable(wxCommandEvent& event);
+        
         wxTextCtrl   *m_txtCtrlCallSign; // TODO: this should be renamed to tx_txtmsg, and rename all related incl persis strge
 
         wxCheckBox* m_ckHalfDuplex;
 
         wxNotebook  *m_notebook;
         wxNotebookPage *m_reportingTab; // txt msg/PSK Reporter
+        wxNotebookPage *m_rigControlTab; // Rig Control
         wxNotebookPage *m_displayTab; // Waterfall color, other display config
         wxNotebookPage *m_keyerTab; // Voice Keyer
         wxNotebookPage *m_modemTab; // 700/OFDM/duplex
         wxNotebookPage *m_simulationTab; // testing/interference
-        wxNotebookPage *m_interfacingTab; // UDP
         wxNotebookPage *m_debugTab; // Debug
         
+        /* Hamlib options */
+        wxCheckBox   *m_ckboxUseAnalogModes;
+        wxCheckBox   *m_ckboxEnableFreqModeChanges;
+        wxCheckBox   *m_ckboxEnableSpacebarForPTT;
+        
         /* Waterfall color */
         wxRadioButton *m_waterfallColorScheme1; // Multicolored
         wxRadioButton *m_waterfallColorScheme2; // Black & white
@@ -98,6 +103,10 @@ class OptionsDlg : public wxDialog
         wxTextCtrl   *m_txtCtrlVoiceKeyerRxPause;
         wxTextCtrl   *m_txtCtrlVoiceKeyerRepeats;
 
+        /* Quick Record */
+        wxButton     *m_buttonChooseQuickRecordPath;
+        wxTextCtrl   *m_txtCtrlQuickRecordPath;
+        
         /* test frames, other simulated channel impairments */
 
         wxCheckBox   *m_ckboxTestFrame;
@@ -117,14 +126,15 @@ class OptionsDlg : public wxDialog
         wxRadioButton *m_rb_textEncoding1;
         wxRadioButton *m_rb_textEncoding2;
 
-        wxCheckBox   *m_ckbox_udp_enable;
-        wxTextCtrl   *m_txt_udp_port;
-        wxButton*     m_btn_udp_test;
-
-        wxCheckBox    *m_ckbox_psk_enable;
+        wxCheckBox    *m_ckboxReportingEnable;
         wxTextCtrl    *m_txt_callsign;
         wxTextCtrl    *m_txt_grid_square;
         
+        wxCheckBox    *m_ckboxPskReporterEnable;
+        
+        wxCheckBox    *m_ckboxFreeDVReporterEnable;
+        wxTextCtrl    *m_freedvReporterHostname;
+        
         wxButton*     m_BtnFifoReset;
         wxStaticText  *m_textFifos;
         wxStaticText  *m_textPA1;
@@ -146,17 +156,20 @@ class OptionsDlg : public wxDialog
         wxCheckBox*  m_ckboxSingleRxThread;
         wxTextCtrl*  m_statsResetTime;
         
+        wxCheckBox*  m_ckbox_use_utc_time;
+        
         unsigned int  event_in_serial, event_out_serial;
 
         void OnChooseVoiceKeyerWaveFile(wxCommandEvent& event);
+        void OnChooseQuickRecordPath(wxCommandEvent& event);
 
      private:
-         void updatePSKReporterState();
+         void updateReportingState();
          void updateChannelNoiseState();
          void updateAttnCarrierState();
          void updateToneState();
-         void updateUDPState();
          void updateMultipleRxState();
+         void updateRigControlState();
          
          bool sessionActive_;
 };
