@@ -59,7 +59,7 @@ ComPortsDlg::ComPortsDlg(wxWindow* parent, wxWindowID id, const wxString& title,
 
     wxStaticBox* hamlibBox = new wxStaticBox(panel, wxID_ANY, _("Hamlib Settings"));
     wxStaticBoxSizer* staticBoxSizer18 = new wxStaticBoxSizer( hamlibBox, wxHORIZONTAL);
-    wxGridSizer* gridSizerhl = new wxGridSizer(6, 2, 0, 0);
+    wxGridSizer* gridSizerhl = new wxGridSizer(7, 2, 0, 0);
     staticBoxSizer18->Add(gridSizerhl, 1, wxEXPAND|wxALIGN_LEFT, 5);
 
     /* Use Hamlib for PTT checkbox. */
@@ -100,7 +100,20 @@ ComPortsDlg::ComPortsDlg(wxWindow* parent, wxWindowID id, const wxString& title,
                       0, wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT, 20);
     m_cbSerialRate = new wxComboBox(hamlibBox, wxID_ANY, wxEmptyString, wxDefaultPosition, wxSize(140, -1), 0, NULL, wxCB_DROPDOWN);
     gridSizerhl->Add(m_cbSerialRate, 0, wxALIGN_CENTER_VERTICAL, 0);
+    
+    /* Hamlib PTT Method combobox. */
 
+    gridSizerhl->Add(new wxStaticText(hamlibBox, wxID_ANY, _("PTT uses:"), wxDefaultPosition, wxDefaultSize, 0), 
+                      0, wxALIGN_CENTER_VERTICAL |  wxALIGN_RIGHT, 20);
+    m_cbPttMethod = new wxComboBox(hamlibBox, wxID_ANY, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
+    m_cbPttMethod->SetSize(wxSize(140, -1));
+    gridSizerhl->Add(m_cbPttMethod, 0, wxALIGN_CENTER_VERTICAL, 0);
+    
+    // Add valid PTT options to combo box.
+    m_cbPttMethod->Append(wxT("CAT"));
+    m_cbPttMethod->Append(wxT("RTS"));
+    m_cbPttMethod->Append(wxT("DTR"));
+    
     gridSizerhl->Add(new wxStaticText(hamlibBox, wxID_ANY, _("Serial Params:"), wxDefaultPosition, wxDefaultSize, 0), 
                       0, wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT, 20);
     m_cbSerialParams = new wxStaticText(hamlibBox, wxID_ANY, _(""), wxDefaultPosition, wxDefaultSize, 0);
@@ -322,7 +335,7 @@ void ComPortsDlg::populatePortList()
 #ifdef __FreeBSD__
     if(glob("/dev/tty*", GLOB_MARK, NULL, &gl)==0) {
 #else
-    if(glob("/dev/tty.*", GLOB_MARK, NULL, &gl)==0) {
+    if(glob("/dev/cu.*", GLOB_MARK, NULL, &gl)==0) {
 #endif
         for(unsigned int i=0; i<gl.gl_pathc; i++) {
             if(gl.gl_pathv[i][strlen(gl.gl_pathv[i])-1]=='/')
@@ -437,6 +450,8 @@ void ComPortsDlg::ExchangeData(int inout)
 
         m_tcIcomCIVHex->SetValue(wxString::Format(wxT("%02X"), wxGetApp().m_intHamlibIcomCIVHex));
         
+        m_cbPttMethod->SetSelection((int)wxGetApp().m_hamlibPttType);
+        
         /* Serial PTT */
 
         m_ckUseSerialPTT->SetValue(wxGetApp().m_boolUseSerialPTT);
@@ -484,11 +499,14 @@ void ComPortsDlg::ExchangeData(int inout)
         }
         if (g_verbose) fprintf(stderr, "serial rate: %d\n", wxGetApp().m_intHamlibSerialRate);
 
+        wxGetApp().m_hamlibPttType = (Hamlib::PttType)m_cbPttMethod->GetSelection();
+        
         pConfig->Write(wxT("/Hamlib/UseForPTT"), wxGetApp().m_boolHamlibUseForPTT);
         pConfig->Write(wxT("/Hamlib/RigNameStr"), wxGetApp().m_strHamlibRigName);
         pConfig->Write(wxT("/Hamlib/SerialPort"), wxGetApp().m_strHamlibSerialPort);
         pConfig->Write(wxT("/Hamlib/SerialRate"), wxGetApp().m_intHamlibSerialRate);
-
+        pConfig->Write(wxT("/Hamlib/PttType"), (long)wxGetApp().m_hamlibPttType);
+        
         /* Serial settings */
 
         wxGetApp().m_boolUseSerialPTT           = m_ckUseSerialPTT->IsChecked();
@@ -560,44 +578,48 @@ void ComPortsDlg::OnTest(wxCommandEvent& event) {
         long hexAddress = 0;
         m_tcIcomCIVHex->GetValue().ToLong(&hexAddress, 16);
         
+        auto pttType = (Hamlib::PttType)m_cbPttMethod->GetSelection();
+
         // display serial params
 
         if (g_verbose) fprintf(stderr, "serial rate: %d\n", serial_rate);
 
-        // try to open rig
+        if (wxGetApp().CanAccessSerialPort((const char*)port.ToUTF8()))
+        {
+            // try to open rig
+            Hamlib *hamlib = wxGetApp().m_hamlib; 
+            bool status = hamlib->connect(rig, port.mb_str(wxConvUTF8), serial_rate, hexAddress, pttType);
+            if (status == false) {
+                wxMessageBox("Couldn't connect to Radio with Hamlib.  Make sure the Hamlib serial Device, Rate, and Params match your radio", 
+                wxT("Error"), wxOK | wxICON_ERROR, this);
+                return;
+            }
+            else {
+                wxString hamlib_serial_config;
+                hamlib_serial_config.sprintf(" %d, %d, %d", 
+                                             hamlib->get_serial_rate(),
+                                             hamlib->get_data_bits(),
+                                             hamlib->get_stop_bits());
+                m_cbSerialParams->SetLabel(hamlib_serial_config);
+           }
 
-        Hamlib *hamlib = wxGetApp().m_hamlib; 
-        bool status = hamlib->connect(rig, port.mb_str(wxConvUTF8), serial_rate, hexAddress);
-        if (status == false) {
-            wxMessageBox("Couldn't connect to Radio with Hamlib.  Make sure the Hamlib serial Device, Rate, and Params match your radio", 
-            wxT("Error"), wxOK | wxICON_ERROR, this);
-            return;
-        }
-        else {
-            wxString hamlib_serial_config;
-            hamlib_serial_config.sprintf(" %d, %d, %d", 
-                                         hamlib->get_serial_rate(),
-                                         hamlib->get_data_bits(),
-                                         hamlib->get_stop_bits());
-            m_cbSerialParams->SetLabel(hamlib_serial_config);
-       }
+            // toggle PTT
 
-        // toggle PTT
+            wxString hamlibError;
+            if (hamlib->ptt(true, hamlibError) == false) {
+                wxMessageBox(wxString("Hamlib PTT Error: ") + hamlibError + 
+                             wxString(".  Make sure the Hamlib serial Device, Rate, and Params match your radio"), 
+                             wxT("Error"), wxOK | wxICON_ERROR, this);
+                return;
+            }
 
-        wxString hamlibError;
-        if (hamlib->ptt(true, hamlibError) == false) {
-            wxMessageBox(wxString("Hamlib PTT Error: ") + hamlibError + 
-                         wxString(".  Make sure the Hamlib serial Device, Rate, and Params match your radio"), 
-                         wxT("Error"), wxOK | wxICON_ERROR, this);
-            return;
-        }
+            wxSleep(1);
 
-        wxSleep(1);
-
-        if (hamlib->ptt(false, hamlibError) == false) {
-            wxMessageBox(wxString("Hamlib PTT Error: ") + hamlibError +
-                         wxString(".  Make sure the Hamlib serial Device, Rate, and Params match your radio"), 
-                         wxT("Error"), wxOK | wxICON_ERROR, this);
+            if (hamlib->ptt(false, hamlibError) == false) {
+                wxMessageBox(wxString("Hamlib PTT Error: ") + hamlibError +
+                             wxString(".  Make sure the Hamlib serial Device, Rate, and Params match your radio"), 
+                             wxT("Error"), wxOK | wxICON_ERROR, this);
+            }
         }
     }
 
@@ -611,29 +633,32 @@ void ComPortsDlg::OnTest(wxCommandEvent& event) {
         if (g_verbose) fprintf(stderr, "opening serial port: ");
         fputs(ctrlport.c_str(), stderr);            // don't escape crazy Microsoft bakslash-ified comm port names
         if (g_verbose) fprintf(stderr,"\n");
+        
+        if (wxGetApp().CanAccessSerialPort((const char*)ctrlport.ToUTF8()))
+        {
+            bool success = serialport->openport(ctrlport.c_str(),
+                                                m_rbUseRTS->GetValue(),
+                                                m_ckRTSPos->IsChecked(),
+                                                m_rbUseDTR->GetValue(),
+                                                m_ckDTRPos->IsChecked());
 
-        bool success = serialport->openport(ctrlport.c_str(),
-                                            m_rbUseRTS->GetValue(),
-                                            m_ckRTSPos->IsChecked(),
-                                            m_rbUseDTR->GetValue(),
-                                            m_ckDTRPos->IsChecked());
+            if (g_verbose) fprintf(stderr, "serial port open\n");
 
-        if (g_verbose) fprintf(stderr, "serial port open\n");
+            if (!success) {
+                wxString errorMessage = "Couldn't open serial port " + ctrlport + ". This is likely due to not having permission to access the chosen port.";
+                wxMessageBox(errorMessage, wxT("Error"), wxOK | wxICON_ERROR, this);
+            }
 
-        if (!success) {
-            wxString errorMessage = "Couldn't open serial port " + ctrlport + ". This is likely due to not having permission to access the chosen port.";
-            wxMessageBox(errorMessage, wxT("Error"), wxOK | wxICON_ERROR, this);
+            // assert PTT port for 1 sec
+
+            serialport->ptt(true);
+            wxSleep(1);
+            serialport->ptt(false);
+
+            if (g_verbose) fprintf(stderr, "closing serial port\n");
+            serialport->closeport();
+            if (g_verbose) fprintf(stderr, "serial port closed\n");
         }
-
-        // assert PTT port for 1 sec
-
-        serialport->ptt(true);
-        wxSleep(1);
-        serialport->ptt(false);
-
-        if (g_verbose) fprintf(stderr, "closing serial port\n");
-        serialport->closeport();
-        if (g_verbose) fprintf(stderr, "serial port closed\n");
     }
     
 }
@@ -720,6 +745,7 @@ void ComPortsDlg::updateControlState()
     m_cbSerialPort->Enable(m_ckUseHamlibPTT->GetValue());
     m_cbSerialRate->Enable(m_ckUseHamlibPTT->GetValue());
     m_tcIcomCIVHex->Enable(m_ckUseHamlibPTT->GetValue());
+    m_cbPttMethod->Enable(m_ckUseHamlibPTT->GetValue());
 
     m_cbCtlDevicePath->Enable(m_ckUseSerialPTT->GetValue());
     m_rbUseDTR->Enable(m_ckUseSerialPTT->GetValue());
