@@ -59,6 +59,7 @@ public:
     void setRunTimeOptions(bool clip, bool bpf);
     
     const char* getCurrentModeStr() const;
+    const char* getCurrentTxModeStr() const;
     bool usingTestFrames() const;
     void resetTestFrameStats();
     void resetBitStats();
@@ -166,6 +167,7 @@ private:
     
     std::deque<reliable_text_t> reliableText_;
     std::string receivedReliableText_;
+    std::mutex reliableTextMutex_;
     
     int preProcessRxFn_(ParallelStep* ps);
     int postProcessRxFn_(ParallelStep* ps);
