@@ -24,6 +24,7 @@
 #include <vector>
 #include <algorithm>
 #include <chrono>
+#include <sstream>
 
 using namespace std::chrono_literals;
 
@@ -47,8 +48,13 @@ Hamlib::Hamlib() :
     m_freqBox(NULL),
     m_currFreq(0),
     m_currMode(RIG_MODE_USB),
+    m_origFreq(0),
+    m_origMode(RIG_MODE_USB),
     m_vhfUhfMode(false),
-    threadRunning_(false)  {
+    pttSet_(false),
+    updatesSuppressed_(false),
+    threadRunning_(false),
+    readOnly_(false)  {
     /* Stop hamlib from spewing info to stderr. */
     rig_set_debug(RIG_DEBUG_NONE);
 
@@ -129,7 +135,14 @@ void Hamlib::populateComboBox(wxComboBox *cb) {
     }
 }
 
-bool Hamlib::connect(unsigned int rig_index, const char *serial_port, const int serial_rate, const int civ_hex) {
+void Hamlib::suppressFrequencyModeUpdates(bool suppress)
+{
+    updatesSuppressed_ = suppress;
+}
+
+bool Hamlib::connect(unsigned int rig_index, const char *serial_port, const int serial_rate, const int civ_hex, const PttType pttType) {
+    m_origFreq = 0;
+    m_origMode = RIG_MODE_USB;
 
     /* Look up model from index. */
 
@@ -173,22 +186,49 @@ bool Hamlib::connect(unsigned int rig_index, const char *serial_port, const int
         if (g_verbose) fprintf(stderr, "hamlib: ignoring CI-V configuration due to non-Icom radio\r\n");
     }
 
-#if defined(HAMLIB_FILPATHLEN)
-    strncpy(m_rig->state.rigport.pathname, serial_port, HAMLIB_FILPATHLEN - 1);
-#else 
-    strncpy(m_rig->state.rigport.pathname, serial_port, FILPATHLEN - 1);
-#endif // HAMLIB_FILPATHLEN
+    rig_set_conf(m_rig, rig_token_lookup(m_rig, "rig_pathname"), serial_port);
 
     if (serial_rate) {
         if (g_verbose) fprintf(stderr, "hamlib: setting serial rate: %d\n", serial_rate);
-        m_rig->state.rigport.parm.serial.rate = serial_rate;
+        std::stringstream ss;
+        ss << serial_rate;
+        rig_set_conf(m_rig, rig_token_lookup(m_rig, "serial_speed"), ss.str().c_str());
     }
-    if (g_verbose) fprintf(stderr, "hamlib: serial rate: %d\n", m_rig->state.rigport.parm.serial.rate);
-    if (g_verbose) fprintf(stderr, "hamlib: data_bits..: %d\n", m_rig->state.rigport.parm.serial.data_bits);
-    if (g_verbose) fprintf(stderr, "hamlib: stop_bits..: %d\n", m_rig->state.rigport.parm.serial.stop_bits);
+    if (g_verbose) fprintf(stderr, "hamlib: serial rate: %d\n", get_serial_rate());
+    if (g_verbose) fprintf(stderr, "hamlib: data_bits..: %d\n", get_data_bits());
+    if (g_verbose) fprintf(stderr, "hamlib: stop_bits..: %d\n", get_stop_bits());
 
+    // Set PTT type as needed.
+    switch(pttType)
+    {
+        case PTT_VIA_RTS:
+            rig_set_conf(m_rig, rig_token_lookup(m_rig, "ptt_type"), "RTS");
+            break;
+        case PTT_VIA_DTR:
+            rig_set_conf(m_rig, rig_token_lookup(m_rig, "ptt_type"), "DTR");
+            break;
+        case PTT_VIA_CAT:
+        default:
+            break;
+    }
+    
     if (rig_open(m_rig) == RIG_OK) {
-        if (g_verbose) fprintf(stderr, "hamlib: rig_open() OK\n");        
+        if (g_verbose) fprintf(stderr, "hamlib: rig_open() OK\n");
+        
+        // Determine whether we have multiple VFOs.
+        multipleVfos_ = false;
+        vfo_t vfo;
+        if (rig_get_vfo (m_rig, &vfo) == RIG_OK && (m_rig->state.vfo_list & RIG_VFO_B))
+        {
+            multipleVfos_ = true;
+        }
+
+        // Get current frequency and mode when we first connect so we can 
+        // revert on close.        
+        update_from_hamlib_();
+        m_origFreq = m_currFreq;
+        m_origMode = m_currMode;
+
         return true;
     }
     if (g_verbose) fprintf(stderr, "hamlib: rig_open() failed ...\n");
@@ -200,15 +240,21 @@ bool Hamlib::connect(unsigned int rig_index, const char *serial_port, const int
 }
 
 int Hamlib::get_serial_rate(void) {
-    return m_rig->state.rigport.parm.serial.rate;
+    char buf[128];
+    rig_get_conf(m_rig, rig_token_lookup(m_rig, "serial_speed"), buf);
+    return atoi(buf);
 }
 
 int Hamlib::get_data_bits(void) {
-    return m_rig->state.rigport.parm.serial.data_bits;
+    char buf[128];
+    rig_get_conf(m_rig, rig_token_lookup(m_rig, "data_bits"), buf);
+    return atoi(buf);
 }
 
 int Hamlib::get_stop_bits(void) {
-    return m_rig->state.rigport.parm.serial.stop_bits;
+    char buf[128];
+    rig_get_conf(m_rig, rig_token_lookup(m_rig, "stop_bits"), buf);
+    return atoi(buf);
 }
 
 bool Hamlib::ptt(bool press, wxString &hamlibError) {
@@ -220,20 +266,23 @@ bool Hamlib::ptt(bool press, wxString &hamlibError) {
     if(!m_rig)
         return false;
 
-    /* TODO(Joel): make ON_DATA and ON configurable. */
-
     ptt_t on = press ? RIG_PTT_ON : RIG_PTT_OFF;
 
-    /* TODO(Joel): what should the VFO option be? */
-
-    int retcode = rig_set_ptt(m_rig, RIG_VFO_CURR, on);
-    if (g_verbose) fprintf(stderr,"Hamlib::ptt: rig_set_ptt returned: %d\n", retcode);
-    if (retcode != RIG_OK ) {
-        if (g_verbose) fprintf(stderr, "rig_set_ptt: error = %s \n", rigerror(retcode));
-        hamlibError = rigerror(retcode);
+    int result = rig_set_ptt(m_rig, RIG_VFO_CURR, on);
+    if (result != RIG_OK) 
+    {
+        if (g_verbose) fprintf(stderr, "rig_set_ptt: error = %s \n", rigerror(result));
     }
-
-    return retcode == RIG_OK;
+    else
+    {
+        pttSet_ = press;
+        if (!press)
+        {
+            update_frequency_and_mode();
+        }
+    }
+    
+    return result == RIG_OK;
 }
 
 int Hamlib::update_frequency_and_mode(void)
@@ -249,7 +298,7 @@ int Hamlib::update_frequency_and_mode(void)
     return 0;
 }
 
-void Hamlib::enable_mode_detection(wxStaticText* statusBox, wxTextCtrl* freqBox, bool vhfUhfMode)
+void Hamlib::enable_mode_detection(wxStaticText* statusBox, wxComboBox* freqBox, bool vhfUhfMode)
 {
     // Set VHF/UHF mode. This governs whether FM is an acceptable mode for the detection display.
     m_vhfUhfMode = vhfUhfMode;
@@ -274,8 +323,133 @@ void Hamlib::disable_mode_detection()
     {
         statusUpdateThread_.join();
     }
+
 }
 
+void Hamlib::setMode(bool analog)
+{
+    if (m_rig == nullptr || pttSet_ || readOnly_)
+    {
+        // Ignore if not connected or if transmitting
+        return;
+    }
+    
+    // Widest 60 meter allocation is 5.250-5.450 MHz per https://en.wikipedia.org/wiki/60-meter_band.
+    auto frequencyHz = get_frequency();
+    bool is60MeterBand = frequencyHz >= 5250000 && frequencyHz <= 5450000;
+    
+    // Update color based on the mode and current frequency.
+    bool isUsbFreq = frequencyHz >= 10000000 || is60MeterBand;
+    bool isLsbFreq = frequencyHz < 10000000 && !is60MeterBand;
+    bool isFmFreq = frequencyHz >= 29510000;
+    
+    // Determine mode to switch to
+    rmode_t mode = RIG_MODE_NONE;
+    if (m_vhfUhfMode && isFmFreq)
+    {
+        mode = !analog ? RIG_MODE_PKTFM : RIG_MODE_FM;
+    }
+    else if (isUsbFreq)
+    {
+        mode = !analog ? RIG_MODE_PKTUSB : RIG_MODE_USB;
+    }
+    else if (isLsbFreq)
+    {
+        mode = !analog ? RIG_MODE_PKTLSB : RIG_MODE_LSB;
+    }
+    else
+    {
+        assert(0);
+    }
+    
+    vfo_t currVfo = getCurrentVfo_(); 
+    setModeHelper_(currVfo, mode);
+}
+
+void Hamlib::setFrequencyAndMode(uint64_t frequencyHz, bool analog)
+{
+    if (m_rig == nullptr || pttSet_ || readOnly_)
+    {
+        // Ignore if not connected or if transmitting
+        return;
+    }
+    
+    vfo_t currVfo = getCurrentVfo_(); 
+    setFrequencyHelper_(currVfo, frequencyHz);
+    setMode(analog);
+}
+  
+void Hamlib::setModeHelper_(vfo_t currVfo, rmode_t mode)
+{
+    bool setOkay = false;
+    
+modeAttempt:
+    int result = rig_set_mode(m_rig, currVfo, mode, RIG_PASSBAND_NOCHANGE);
+    if (result != RIG_OK && currVfo == RIG_VFO_CURR)
+    {
+        if (g_verbose) fprintf(stderr, "rig_set_mode: error = %s \n", rigerror(result));
+    }
+    else if (result != RIG_OK)
+    {
+        // We supposedly have multiple VFOs but ran into problems 
+        // trying to get information about the supposed active VFO.
+        // Make a last ditch effort using RIG_VFO_CURR before fully failing.
+        currVfo = RIG_VFO_CURR;
+        goto modeAttempt;
+    }
+    else
+    {
+        setOkay = true;
+    }
+
+    // If we're able to set either frequency or mode, we should update UI accordingly.
+    // The actual configuration of the radio (in case of failure) will auto-update within
+    // a few seconds after this update.
+    if (setOkay)
+    {
+        m_currMode = mode;
+        if (m_modeBox != nullptr)
+        {
+            m_modeBox->CallAfter([&]() { update_mode_status(); });
+        }
+    }
+}
+
+void Hamlib::setFrequencyHelper_(vfo_t currVfo, uint64_t frequencyHz)
+{
+    bool setOkay = false;
+    
+freqAttempt:
+    int result = rig_set_freq(m_rig, currVfo, frequencyHz);
+    if (result != RIG_OK && currVfo == RIG_VFO_CURR)
+    {
+        if (g_verbose) fprintf(stderr, "rig_set_freq: error = %s \n", rigerror(result));
+    }
+    else if (result != RIG_OK)
+    {
+        // We supposedly have multiple VFOs but ran into problems 
+        // trying to get information about the supposed active VFO.
+        // Make a last ditch effort using RIG_VFO_CURR before fully failing.
+        currVfo = RIG_VFO_CURR;
+        goto freqAttempt;
+    }
+    else
+    {
+        setOkay = true;
+    }
+    
+    // If we're able to set either frequency or mode, we should update UI accordingly.
+    // The actual configuration of the radio (in case of failure) will auto-update within
+    // a few seconds after this update.
+    if (setOkay)
+    {
+        m_currFreq = frequencyHz;
+        if (m_modeBox != nullptr)
+        {
+            m_modeBox->CallAfter([&]() { update_mode_status(); });
+        }
+    }
+}
 
 void Hamlib::statusUpdateThreadEntryFn_()
 {
@@ -291,7 +465,8 @@ void Hamlib::statusUpdateThreadEntryFn_()
             m_modeBox->SetLabel(wxT("unk"));
             m_modeBox->Enable(false);
             m_modeBox->SetForegroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT));
-            m_modeBox = NULL;
+            m_freqBox = nullptr;
+            m_modeBox = nullptr;
         });
         
         threadRunning_ = false;
@@ -325,33 +500,53 @@ void Hamlib::statusUpdateThreadEntryFn_()
 
 void Hamlib::update_from_hamlib_()
 {
+    if (pttSet_ || updatesSuppressed_)
+    {
+        // ignore Hamlib update when PTT active or we're otherwise suppressing updates.
+        return;
+    }
+    
     rmode_t mode = RIG_MODE_NONE;
     pbwidth_t passband = 0;
-    vfo_t currVfo = RIG_VFO_A;
-    int result = rig_get_vfo(m_rig, &currVfo);
-    if (result != RIG_OK && result != -RIG_ENAVAIL)
+    vfo_t currVfo = getCurrentVfo_();    
+
+modeAttempt:
+    int result = rig_get_mode(m_rig, currVfo, &mode, &passband);
+    if (result != RIG_OK && currVfo == RIG_VFO_CURR)
     {
-        if (g_verbose) fprintf(stderr, "rig_get_vfo: error = %s \n", rigerror(result));
+        if (g_verbose) fprintf(stderr, "rig_get_mode: error = %s \n", rigerror(result));
+    }
+    else if (result != RIG_OK)
+    {
+        // We supposedly have multiple VFOs but ran into problems 
+        // trying to get information about the supposed active VFO.
+        // Make a last ditch effort using RIG_VFO_CURR before fully failing.
+        currVfo = RIG_VFO_CURR;
+        goto modeAttempt;
     }
     else
     {
-        result = rig_get_mode(m_rig, currVfo, &mode, &passband);
-        if (result != RIG_OK)
+freqAttempt:
+        freq_t freq = 0;
+        result = rig_get_freq(m_rig, currVfo, &freq);
+        if (result != RIG_OK && currVfo == RIG_VFO_CURR)
         {
-            if (g_verbose) fprintf(stderr, "rig_get_mode: error = %s \n", rigerror(result));
+            if (g_verbose) fprintf(stderr, "rig_get_freq: error = %s \n", rigerror(result));
+        }
+        else if (result != RIG_OK)
+        {
+            // We supposedly have multiple VFOs but ran into problems 
+            // trying to get information about the supposed active VFO.
+            // Make a last ditch effort using RIG_VFO_CURR before fully failing.
+            currVfo = RIG_VFO_CURR;
+            goto freqAttempt;
         }
         else
         {
-            freq_t freq = 0;
-            result = rig_get_freq(m_rig, currVfo, &freq);
-            if (result != RIG_OK)
+            m_currMode = mode;
+            m_currFreq = freq;
+            if (m_modeBox != nullptr)
             {
-                if (g_verbose) fprintf(stderr, "rig_get_freq: error = %s \n", rigerror(result));
-            }
-            else
-            {
-                m_currMode = mode;
-                m_currFreq = freq;
                 m_modeBox->CallAfter([&]() { update_mode_status(); });
             }
         }
@@ -365,7 +560,7 @@ void Hamlib::update_mode_status()
         m_modeBox->SetLabel(wxT("USB"));
     else if (m_currMode == RIG_MODE_LSB || m_currMode == RIG_MODE_PKTLSB)
         m_modeBox->SetLabel(wxT("LSB"));
-    else if (m_currMode == RIG_MODE_FM || m_currMode == RIG_MODE_FM)
+    else if (m_currMode == RIG_MODE_FM || m_currMode == RIG_MODE_PKTFM)
         m_modeBox->SetLabel(wxT("FM"));
     else
         m_modeBox->SetLabel(rig_strrmode(m_currMode));
@@ -393,7 +588,7 @@ void Hamlib::update_mode_status()
     }
 
     // Update frequency box
-    m_freqBox->SetValue(wxString::Format("%.1f", m_currFreq/1000));
+    m_freqBox->SetValue(wxString::Format("%.4f", m_currFreq/1000.0/1000.0));
     
     // Refresh
     m_modeBox->Refresh();
@@ -403,9 +598,35 @@ void Hamlib::close(void) {
     if(m_rig) {
         // Turn off status thread if needed.
         disable_mode_detection();
-        
+       
+        // Recover original frequency and mode before closure.
+        if (m_origFreq > 0 && !readOnly_)
+        {
+            auto vfo = getCurrentVfo_();
+            setFrequencyHelper_(vfo, m_origFreq);
+            setModeHelper_(vfo, m_origMode);
+        }
+ 
         rig_close(m_rig);
         rig_cleanup(m_rig);
         m_rig = NULL;
     }
 }
+
+vfo_t Hamlib::getCurrentVfo_()
+{
+    vfo_t vfo = RIG_VFO_CURR;
+    
+    if (multipleVfos_)
+    {
+        int result = rig_get_vfo(m_rig, &vfo);
+        if (result != RIG_OK && result != -RIG_ENAVAIL)
+        {
+            // Note: we'll still attempt operation using RIG_VFO_CURR just in case.
+            if (g_verbose) fprintf(stderr, "rig_get_vfo: error = %s \n", rigerror(result));
+            vfo = RIG_VFO_CURR;
+        }
+    }
+    
+    return vfo;
+}
