@@ -88,7 +88,7 @@
 #include "comp_prim.h"
 #include "hamlib.h"
 #include "serialport.h" 
-#include "pskreporter.h"
+#include "reporting/IReporter.h"
 #include "freedv_interface.h"
 #include "audio/AudioEngineFactory.h"
 #include "audio/IAudioDevice.h"
@@ -165,6 +165,9 @@ class MainApp : public wxApp
         virtual bool        OnCmdLineParsed(wxCmdLineParser& parser);
         virtual int         OnExit();
 
+
+        bool                    CanAccessSerialPort(std::string portName);
+        
         wxString            m_strVendName;
         wxString            m_StrAppName;
 
@@ -199,13 +202,19 @@ class MainApp : public wxApp
         int                 m_intVoiceKeyerRxPause;
         int                 m_intVoiceKeyerRepeats;
 
+        wxString            m_txtQuickRecordPath;
+    
+        bool                m_boolEnableSpacebarForPTT;
         bool                m_boolHamlibUseForPTT;
+        bool                m_boolHamlibEnableFreqModeChanges;
         unsigned int        m_intHamlibRig;
         wxString            m_strHamlibRigName;
         wxString            m_strHamlibSerialPort;
         unsigned int        m_intHamlibSerialRate;
         unsigned int        m_intHamlibIcomCIVHex;
         Hamlib              *m_hamlib;
+        Hamlib::PttType     m_hamlibPttType;
+        bool                m_boolHamlibUseAnalogModes;
 
         bool                m_boolUseSerialPTT;
         wxString            m_strRigCtrlPort;
@@ -273,10 +282,6 @@ class MainApp : public wxApp
         // optional vox trigger tone
         bool                m_leftChannelVoxTone;
 
-        // UDP control port
-        bool                m_udp_enable;
-        int                 m_udp_port;
-
         // notebook display after tx->rxtransition
         int                 m_rxNbookCtrl;
 
@@ -284,15 +289,23 @@ class MainApp : public wxApp
 
         int                 m_fifoSize_ms;
 
+        // General reporting configuration
+        bool                m_reportingEnabled;
+        wxString            m_reportingCallsign;
+        wxString            m_reportingGridSquare;
+        uint64_t            m_reportingFrequency;
+        
         // PSK Reporter configuration
-        bool                m_psk_enable;
-        wxString            m_psk_callsign;
-        wxString            m_psk_grid_square;
-        uint64_t            m_psk_freq;
+        bool                m_pskReporterEnabled;
+        
+        // FreeDV Reporter configuration
+        bool                m_freedvReporterEnabled;
+        wxString            m_freedvReporterHostname;
+        
+        // Callsign list configuration
+        bool                m_useUTCTime;
 
-        PskReporter*            m_pskReporter;
-        std::string         m_pskPendingCallsign;
-        char                m_pskPendingSnr;
+        std::vector<IReporter*> m_reporters;
         
         // Waterfall display
         int                 m_waterfallColor;
@@ -384,7 +397,6 @@ private:
 };
 
 class TxRxThread;
-class UDPThread;
 
 //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=--=-=-=-=
 // Class MainFrame
@@ -439,12 +451,6 @@ class MainFrame : public TopFrame
 
     void togglePTT(void);
 
-    wxIPV4address           m_udp_addr;
-    wxDatagramSocket       *m_udp_sock;
-    UDPThread              *m_UDPThread;
-    void                    startUDPThread(void);
-    void                    stopUDPThread(void);
-    int                     PollUDP();
     bool                    m_schedule_restore;
 
     // Voice Keyer state machine
@@ -468,7 +474,7 @@ class MainFrame : public TopFrame
         void setsnrBeta(bool snrSlow);
 
         // protected event handlers
-        virtual void topFrame_OnSize( wxSizeEvent& event );
+        virtual void topFrame_OnSize( wxSizeEvent& event ) override;
         virtual void OnCloseFrame(wxCloseEvent& event);
         void OnExitClick(wxCommandEvent& event);
 
@@ -479,42 +485,45 @@ class MainFrame : public TopFrame
         void abortTxStream();
         void abortRxStream();
 
-        void OnTop(wxCommandEvent& event);
-        void OnExit( wxCommandEvent& event );
+        void OnTop(wxCommandEvent& event) override;
+        void OnExit( wxCommandEvent& event ) override;
 
-        void OnToolsEasySetup( wxCommandEvent& event );
-        void OnToolsEasySetupUI( wxUpdateUIEvent& event );
-        void OnToolsAudio( wxCommandEvent& event );
-        void OnToolsAudioUI( wxUpdateUIEvent& event );
-        void OnToolsComCfg( wxCommandEvent& event );
-        void OnToolsComCfgUI( wxUpdateUIEvent& event );
-        void OnToolsFilter( wxCommandEvent& event );
-        void OnToolsOptions(wxCommandEvent& event);
-        void OnToolsOptionsUI(wxUpdateUIEvent& event);
+        void OnToolsEasySetup( wxCommandEvent& event ) override;
+        void OnToolsEasySetupUI( wxUpdateUIEvent& event ) override;
+        void OnToolsFreeDVReporter( wxCommandEvent& event ) override;
+        void OnToolsFreeDVReporterUI( wxUpdateUIEvent& event ) override;
+        void OnToolsAudio( wxCommandEvent& event ) override;
+        void OnToolsAudioUI( wxUpdateUIEvent& event ) override;
+        void OnToolsComCfg( wxCommandEvent& event ) override;
+        void OnToolsComCfgUI( wxUpdateUIEvent& event ) override;
+        void OnToolsFilter( wxCommandEvent& event ) override;
+        void OnToolsOptions(wxCommandEvent& event) override;
+        void OnToolsOptionsUI(wxUpdateUIEvent& event) override;
 
-        void OnPlayFileToMicIn( wxCommandEvent& event );
-        void OnRecFileFromRadio( wxCommandEvent& event );
-        void OnRecFileFromModulator( wxCommandEvent& event);
-        void OnPlayFileFromRadio( wxCommandEvent& event );
+        void OnPlayFileToMicIn( wxCommandEvent& event ) override;
+        void OnRecFileFromRadio( wxCommandEvent& event ) override;
+        void OnRecFileFromModulator( wxCommandEvent& event) override;
+        void OnPlayFileFromRadio( wxCommandEvent& event ) override;
 
-        void OnHelpCheckUpdates( wxCommandEvent& event );
-        void OnHelpCheckUpdatesUI( wxUpdateUIEvent& event );
-        void OnHelpAbout( wxCommandEvent& event );
-        void OnHelpManual( wxCommandEvent& event );
-        void OnCmdSliderScroll( wxScrollEvent& event );
-        void OnCheckSQClick( wxCommandEvent& event );
-        void OnCheckSNRClick( wxCommandEvent& event );
+        void OnHelpCheckUpdates( wxCommandEvent& event ) override;
+        void OnHelpCheckUpdatesUI( wxUpdateUIEvent& event ) override;
+        void OnHelpAbout( wxCommandEvent& event ) override;
+        void OnHelpManual( wxCommandEvent& event ) override;
+        void OnCmdSliderScroll( wxScrollEvent& event ) override;
+        void OnCheckSQClick( wxCommandEvent& event ) override;
+        void OnCheckSNRClick( wxCommandEvent& event ) override;
 
         // Toggle Buttons
         void OnTogBtnSplitClick(wxCommandEvent& event);
-        void OnTogBtnAnalogClick(wxCommandEvent& event);
-        void OnTogBtnPTT( wxCommandEvent& event );
-        void OnTogBtnVoiceKeyerClick (wxCommandEvent& event);
-        void OnTogBtnOnOff( wxCommandEvent& event );
+        void OnTogBtnAnalogClick(wxCommandEvent& event) override;
+        void OnTogBtnPTT( wxCommandEvent& event ) override;
+        void OnTogBtnVoiceKeyerClick (wxCommandEvent& event) override;
+        void OnTogBtnOnOff( wxCommandEvent& event ) override;
+        void OnTogBtnRecord( wxCommandEvent& event ) override;
 
-        void OnCallSignReset( wxCommandEvent& event );
-        void OnBerReset( wxCommandEvent& event );
-        void OnReSync( wxCommandEvent& event );
+        void OnCallSignReset( wxCommandEvent& event ) override;
+        void OnBerReset( wxCommandEvent& event ) override;
+        void OnReSync( wxCommandEvent& event ) override;
 
         //System Events
         void OnPaint(wxPaintEvent& event);
@@ -531,11 +540,16 @@ class MainFrame : public TopFrame
 
         int VoiceKeyerStartTx(void);
 
-        void OnChangeTxMode( wxCommandEvent& event );
+        void OnChangeTxMode( wxCommandEvent& event ) override;
         
-        void OnChangeTxLevel( wxScrollEvent& event );
+        void OnChangeTxLevel( wxScrollEvent& event ) override;
+        
+        void OnChangeReportFrequency( wxCommandEvent& event ) override;
+        void OnChangeReportFrequencyVerify( wxCommandEvent& event ) override;
+        
+        void OnReportFrequencySetFocus(wxFocusEvent& event) override;
+        void OnReportFrequencyKillFocus(wxFocusEvent& event) override;
         
-        void OnChangeReportFrequency( wxCommandEvent& event );
     private:
         std::shared_ptr<IAudioDevice> rxInSoundDevice;
         std::shared_ptr<IAudioDevice> rxOutSoundDevice;
@@ -584,26 +598,11 @@ class MainFrame : public TopFrame
 #if defined(FREEDV_MODE_2020)
         void test2020Mode_();
 #endif // defined(FREEDV_MODE_2020)
-};
-
-//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=--=-=-=-=
-// class UDPThread - waits for UDP messages
-//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=--=-=-=-=
-class UDPThread : public wxThread
-{
-public:
-    UDPThread(void) : wxThread(wxTHREAD_JOINABLE) { m_run = 1; }
-
-    // thread execution starts here
-    void *Entry();
-
-    // called when the thread exits - whether it terminates normally or is
-    // stopped with Delete() (but not when it is Kill()ed!)
-    void OnExit() { }
-
-public:
-    MainFrame              *mf;
-    bool                    m_run;
+        
+        void performFreeDVOn_();
+        void performFreeDVOff_();
+        
+        void executeOnUiThreadAndWait_(std::function<void()> fn);
 };
 
 void resample_for_plot(struct FIFO *plotFifo, short buf[], int length, int fs);
@@ -631,7 +630,4 @@ void my_put_next_rx_char(void *callback_state, char c);
 
 void freq_shift_coh(COMP rx_fdm_fcorr[], COMP rx_fdm[], float foff, float Fs, COMP *foff_phase_rect, int nin);
 
-void UDPSend(int port, char *buf, unsigned int n);
-void UDPInit(void);
-
 #endif //__FDMDV2_MAIN__
