@@ -13,7 +13,6 @@ extern bool  g_modal;
 extern int   g_SquelchActive;
 extern float g_SquelchLevel;
 extern int   g_analog;
-extern int   g_split;
 extern int   g_tx;
 extern int   g_State, g_prev_State;
 extern FreeDVInterface freedvInterface;
@@ -60,6 +59,23 @@ void MainFrame::OnToolsEasySetupUI(wxUpdateUIEvent& event)
     event.Enable(!m_RxRunning);
 }
 
+//-------------------------------------------------------------------------
+// OnToolsFreeDVReporter()
+//-------------------------------------------------------------------------
+void MainFrame::OnToolsFreeDVReporter(wxCommandEvent& event)
+{
+    std::string url = "https://" + wxGetApp().m_freedvReporterHostname.ToStdString() + "/";
+    wxLaunchDefaultBrowser(url);
+}
+
+//-------------------------------------------------------------------------
+// OnToolsFreeDVReporterUI()
+//-------------------------------------------------------------------------
+void MainFrame::OnToolsFreeDVReporterUI(wxUpdateUIEvent& event)
+{
+    event.Enable(wxGetApp().m_freedvReporterHostname.ToStdString() != "");
+}
+
 //-------------------------------------------------------------------------
 // OnToolsAudio()
 //-------------------------------------------------------------------------
@@ -116,7 +132,22 @@ void MainFrame::OnToolsOptions(wxCommandEvent& event)
     optionsDlg->ShowModal();
     
     // Show/hide frequency box based on PSK Reporter status.
-    m_freqBox->Show(wxGetApp().m_psk_enable);
+    m_freqBox->Show(wxGetApp().m_reportingEnabled);
+
+    // Show/hide callsign combo box based on PSK Reporter Status
+    if (wxGetApp().m_reportingEnabled)
+    {
+        m_cboLastReportedCallsigns->Show();
+        m_txtCtrlCallSign->Hide();
+    }
+    else
+    {
+        m_cboLastReportedCallsigns->Hide();
+        m_txtCtrlCallSign->Show();
+    }
+
+    // Relayout window so that the changes can take effect.
+    m_panel->Layout();
 }
 
 //-------------------------------------------------------------------------
@@ -153,8 +184,7 @@ void MainFrame::OnToolsComCfgUI(wxUpdateUIEvent& event)
 //-------------------------------------------------------------------------
 void MainFrame::OnHelpCheckUpdates(wxCommandEvent& event)
 {
-    wxMessageBox("Got Click!", "OnHelpCheckUpdates", wxOK);
-    event.Skip();
+    wxLaunchDefaultBrowser("https://github.com/drowe67/freedv-gui/releases");
 }
 
 //-------------------------------------------------------------------------
@@ -162,7 +192,7 @@ void MainFrame::OnHelpCheckUpdates(wxCommandEvent& event)
 //-------------------------------------------------------------------------
 void MainFrame::OnHelpCheckUpdatesUI(wxUpdateUIEvent& event)
 {
-    event.Enable(false);
+    event.Enable(!m_RxRunning);
 }
 
 //-------------------------------------------------------------------------
@@ -209,17 +239,29 @@ bool MainFrame::OpenHamlibRig() {
     int rig = wxGetApp().m_intHamlibRig;
     wxString port = wxGetApp().m_strHamlibSerialPort;
     int serial_rate = wxGetApp().m_intHamlibSerialRate;
-    bool status = wxGetApp().m_hamlib->connect(rig, port.mb_str(wxConvUTF8), serial_rate, wxGetApp().m_intHamlibIcomCIVHex);
-    if (status == false)
+    if (wxGetApp().CanAccessSerialPort((const char*)port.ToUTF8()))
     {
-        wxMessageBox("Couldn't connect to Radio with hamlib", wxT("Error"), wxOK | wxICON_ERROR, this);
+        bool status = wxGetApp().m_hamlib->connect(rig, port.mb_str(wxConvUTF8), serial_rate, wxGetApp().m_intHamlibIcomCIVHex, wxGetApp().m_hamlibPttType);
+        if (status == false)
+        {
+            wxMessageBox("Couldn't connect to Radio with hamlib", wxT("Error"), wxOK | wxICON_ERROR, this);
+        }
+        else
+        {
+            wxGetApp().m_hamlib->readOnly(!wxGetApp().m_boolHamlibEnableFreqModeChanges);
+            if (wxGetApp().m_boolHamlibEnableFreqModeChanges)
+            {
+                wxGetApp().m_hamlib->setFrequencyAndMode(wxGetApp().m_reportingFrequency, wxGetApp().m_boolHamlibUseAnalogModes ? true : g_analog);
+            }
+            wxGetApp().m_hamlib->enable_mode_detection(m_txtModeStatus, m_cboReportFrequency, g_mode == FREEDV_MODE_2400B);
+        }
+    
+        return status;
     }
     else
     {
-        wxGetApp().m_hamlib->enable_mode_detection(m_txtModeStatus, m_txtCtrlReportFrequency, g_mode == FREEDV_MODE_2400B);
+        return false;
     }
-    
-    return status;
 }
 
 //-------------------------------------------------------------------------
@@ -368,7 +410,7 @@ int MainApp::FilterEvent(wxEvent& event)
             // only use space to toggle PTT if we are running and no modal dialogs (like options) up
             //fprintf(stderr,"frame->m_RxRunning: %d g_modal: %d\n",
             //        frame->m_RxRunning, g_modal);
-            if (frame->m_RxRunning && !g_modal) {
+            if (frame->m_RxRunning && !g_modal && wxGetApp().m_boolEnableSpacebarForPTT) {
 
                 // space bar controls rx/rx if keyer not running
                 if (frame->vk_state == VK_IDLE) {
@@ -482,15 +524,15 @@ void MainFrame::togglePTT(void) {
     m_textLevel->SetLabel(wxT(""));
     m_gaugeLevel->SetValue(0);
     endingTx = false;
-}
+    
+    // Report TX change to registered reporters
+    for (auto& obj : wxGetApp().m_reporters)
+    {
+        obj->transmit(freedvInterface.getCurrentTxModeStr(), g_tx);
+    }
 
-
-void MainFrame::OnTogBtnSplitClick(wxCommandEvent& event) {
-    if (g_split)
-        g_split = 0;
-    else
-        g_split = 1;
-    event.Skip();
+    // Change button color depending on TX status.
+    m_btnTogPTT->SetBackgroundColour(g_tx ? *wxRED : wxNullColour);
 }
 
 //-------------------------------------------------------------------------
@@ -509,6 +551,20 @@ void MainFrame::OnTogBtnAnalogClick (wxCommandEvent& event)
         m_panelWaterfall->setFs(freedvInterface.getRxModemSampleRate());
     }
 
+    // Report analog change to registered reporters
+    for (auto& obj : wxGetApp().m_reporters)
+    {
+        obj->inAnalogMode(g_analog);
+    }
+    
+    if (wxGetApp().m_hamlib != nullptr && 
+        wxGetApp().m_reportingFrequency > 0 &&
+        wxGetApp().m_boolHamlibEnableFreqModeChanges)
+    {
+        // Request mode change on the radio side
+        wxGetApp().m_hamlib->setMode(wxGetApp().m_boolHamlibUseAnalogModes ? true : g_analog);
+    }
+
     g_State = g_prev_State = 0;
     freedvInterface.getCurrentRxModemStats()->snr_est = 0;
 
@@ -558,25 +614,73 @@ void MainFrame::OnBerReset(wxCommandEvent& event)
     resetStats_();
 }
 
-void MainFrame::OnChangeReportFrequency( wxCommandEvent& event )
+void MainFrame::OnChangeReportFrequencyVerify( wxCommandEvent& event )
 {
-    wxString freqStr = m_txtCtrlReportFrequency->GetValue();
+    if (wxGetApp().m_hamlib != nullptr && wxGetApp().m_hamlib->isSuppressFrequencyModeUpdates())
+    {
+        return;
+    }
+    
+    OnChangeReportFrequency(event);
+}
+
+void MainFrame::OnChangeReportFrequency( wxCommandEvent& event )
+{    
+    wxString freqStr = m_cboReportFrequency->GetValue();
     if (freqStr.Length() > 0)
     {
-        wxGetApp().m_psk_freq = atof(freqStr.ToUTF8()) * 1000;
-        if (wxGetApp().m_psk_freq > 0)
+        wxGetApp().m_reportingFrequency = atof(freqStr.ToUTF8()) * 1000 * 1000;
+        if (wxGetApp().m_reportingFrequency > 0)
         {
-            m_txtCtrlReportFrequency->SetForegroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT));
+            m_cboReportFrequency->SetForegroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT));
         }
         else
         {
-            m_txtCtrlReportFrequency->SetForegroundColour(wxColor(*wxRED));
+            m_cboReportFrequency->SetForegroundColour(wxColor(*wxRED));
         }
     }
     else
     {
-        wxGetApp().m_psk_freq = 0;
-        m_txtCtrlReportFrequency->SetForegroundColour(wxColor(*wxRED));
+        wxGetApp().m_reportingFrequency = 0;
+        m_cboReportFrequency->SetForegroundColour(wxColor(*wxRED));
+    }
+    
+    // Report current frequency to reporters
+    for (auto& ptr : wxGetApp().m_reporters)
+    {
+        ptr->freqChange(wxGetApp().m_reportingFrequency);
+    }
+    
+    if (wxGetApp().m_hamlib != nullptr && 
+        wxGetApp().m_reportingFrequency > 0 && 
+        wxGetApp().m_reportingFrequency != wxGetApp().m_hamlib->get_frequency() &&
+        wxGetApp().m_boolHamlibEnableFreqModeChanges)
+    {
+        // Request frequency/mode change on the radio side
+        wxGetApp().m_hamlib->setFrequencyAndMode(wxGetApp().m_reportingFrequency, wxGetApp().m_boolHamlibUseAnalogModes ? true : g_analog);
     }
 }
 
+void MainFrame::OnReportFrequencySetFocus(wxFocusEvent& event)
+{
+    if (wxGetApp().m_hamlib != nullptr)
+    {
+        wxGetApp().m_hamlib->suppressFrequencyModeUpdates(true);
+    }
+    
+    TopFrame::OnReportFrequencySetFocus(event);
+}
+
+void MainFrame::OnReportFrequencyKillFocus(wxFocusEvent& event)
+{
+    // Handle any frequency changes as appropriate.
+    wxCommandEvent tmpEvent;
+    OnChangeReportFrequency(tmpEvent);
+    
+    if (wxGetApp().m_hamlib != nullptr)
+    {
+        wxGetApp().m_hamlib->suppressFrequencyModeUpdates(false);
+    }
+    
+    TopFrame::OnReportFrequencyKillFocus(event);
+}
