@@ -56,6 +56,9 @@
 #include <wx/notebook.h>
 #include <wx/listctrl.h>
 #include <wx/collpane.h>
+#include <wx/combo.h>
+
+#include "wxListViewComboPopup.h"
 
 #include "freedv_api.h" // for FREEDV_MODE_*
 
@@ -73,6 +76,8 @@
 
 #define ID_MODE_COLLAPSE 1100
 
+class wxListViewComboPopup;
+
 ///////////////////////////////////////////////////////////////////////////////
 /// Class TopFrame
 ///////////////////////////////////////////////////////////////////////////////
@@ -81,6 +86,7 @@ class TopFrame : public wxFrame
     private:
 
     protected:
+        wxPanel* m_panel;
         wxMenuBar* m_menubarMain;
         wxMenu* file;
         wxMenu* edit;
@@ -94,6 +100,10 @@ class TopFrame : public wxFrame
 
         wxButton*     m_BtnCallSignReset;
         wxTextCtrl*   m_txtCtrlCallSign;
+        
+        wxComboCtrl*   m_cboLastReportedCallsigns;
+        wxListViewComboPopup* m_lastReportedCallsignListView;
+        
         wxStaticText* m_txtModeStatus;
 
         wxStaticText* m_txtTxLevelNum;
@@ -117,6 +127,8 @@ class TopFrame : public wxFrame
 
         wxStaticText  *m_textSync;
         wxButton      *m_BtnReSync;
+        
+        wxToggleButton      *m_audioRecord;
 
         wxRadioButton *m_rb700c;
         wxRadioButton *m_rb700d;
@@ -153,6 +165,8 @@ class TopFrame : public wxFrame
         virtual void OnTop( wxCommandEvent& event ) { event.Skip(); }
         virtual void OnToolsEasySetup( wxCommandEvent& event ) { event.Skip(); }
         virtual void OnToolsEasySetupUI( wxUpdateUIEvent& event ) { event.Skip(); }
+        virtual void OnToolsFreeDVReporter( wxCommandEvent& event ) { event.Skip(); }
+        virtual void OnToolsFreeDVReporterUI( wxUpdateUIEvent& event ) { event.Skip(); }
         virtual void OnToolsAudio( wxCommandEvent& event ) { event.Skip(); }
         virtual void OnToolsAudioUI( wxUpdateUIEvent& event ) { event.Skip(); }
         virtual void OnToolsFilter( wxCommandEvent& event ) { event.Skip(); }
@@ -179,12 +193,12 @@ class TopFrame : public wxFrame
         virtual void OnTogBtnLoopRx( wxCommandEvent& event ) { event.Skip(); }
         virtual void OnTogBtnLoopTx( wxCommandEvent& event ) { event.Skip(); }
         virtual void OnTogBtnOnOff( wxCommandEvent& event ) { event.Skip(); }
-        virtual void OnTogBtnSplitClick( wxCommandEvent& event ) { event.Skip(); }
         virtual void OnTogBtnAnalogClick( wxCommandEvent& event ) { event.Skip(); }
         virtual void OnTogBtnVoiceKeyerClick( wxCommandEvent& event ) { event.Skip(); }
         virtual void OnTogBtnPTT( wxCommandEvent& event ) { event.Skip(); }
+        
+        virtual void OnTogBtnRecord( wxCommandEvent& event ) { event.Skip(); }
 
-        virtual void OnTogBtnSplitClickUI(wxUpdateUIEvent& event) { event.Skip(); }
         virtual void OnTogBtnAnalogClickUI(wxUpdateUIEvent& event) { event.Skip(); }
         virtual void OnTogBtnRxIDUI(wxUpdateUIEvent& event ) { event.Skip(); }
         virtual void OnTogBtnTxIDUI(wxUpdateUIEvent& event ) { event.Skip(); }
@@ -200,19 +214,20 @@ class TopFrame : public wxFrame
         virtual void OnChangeTxLevel( wxScrollEvent& event ) { event.Skip(); }
         
         virtual void OnChangeReportFrequency( wxCommandEvent& event ) { event.Skip(); }
+        virtual void OnChangeReportFrequencyVerify( wxCommandEvent& event ) { event.Skip(); }
         
         virtual void OnChangeCollapseState(wxCollapsiblePaneEvent& event);
         
+        virtual void OnReportFrequencySetFocus(wxFocusEvent& event) { event.Skip(); }
+        virtual void OnReportFrequencyKillFocus(wxFocusEvent& event) { event.Skip(); }
+        
     public:
         wxToggleButton* m_togBtnOnOff;
-        wxToggleButton* m_togBtnSplit;
         wxToggleButton* m_togBtnAnalog;
         wxToggleButton* m_togBtnVoiceKeyer;
         wxToggleButton* m_btnTogPTT;
-        wxToggleButton* m_togBtnLoopRx;
-        wxToggleButton* m_togBtnLoopTx;
         wxAuiNotebook* m_auiNbookCtrl;
-        wxTextCtrl*   m_txtCtrlReportFrequency;
+        wxComboBox*   m_cboReportFrequency;
         wxStaticBox*  m_freqBox;
 
         TopFrame( wxWindow* parent, wxWindowID id = wxID_ANY, const wxString& title = _("FreeDV "), const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxSize(561,300 ), long style = wxDEFAULT_FRAME_STYLE|wxRESIZE_BORDER );
